<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>CircleConcentric</name>
    <message>
        <location filename="../CircleConcentric.ui" line="+17"/>
        <source>Distance:</source>
        <translation>距离：</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Number:</source>
        <translation>数量：</translation>
    </message>
    <message>
        <location filename="../CircleConcentricInit.js" line="+2"/>
        <source>&amp;Concentric (with Distance)</source>
        <translation>同心圆（根据偏移距离）(&amp;C)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Draw concentric circle</source>
        <translation>画同心圆</translation>
    </message>
</context>
</TS>
